@@ -31,7 +31,7 @@ import io
 import logging
 import mock
 import os
-import unittest2 as unittest
+import unittest
 import urllib
 import random
 import socket
